kenchi\.outlier\_detection\.distance\_based module
==================================================

.. automodule:: kenchi.outlier_detection.distance_based
    :members:
    :undoc-members:
    :show-inheritance:
